
penman.codec
============

.. automodule:: penman.codec

   .. autoclass:: PENMANCodec

      .. automethod:: decode
      .. automethod:: iterdecode
      .. automethod:: parse
      .. automethod:: iterparse
      .. automethod:: parse_triples

      .. automethod:: encode
      .. automethod:: format
      .. automethod:: format_triples
